summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmlistpatternedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmlistpatternedit.h')
-rw-r--r--kpovmodeler/pmlistpatternedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmlistpatternedit.h b/kpovmodeler/pmlistpatternedit.h
index 703a5944..4e80e4d8 100644
--- a/kpovmodeler/pmlistpatternedit.h
+++ b/kpovmodeler/pmlistpatternedit.h
@@ -38,12 +38,13 @@ class TQLabel;
class PMListPatternEdit : public PMDialogEditBase
{
Q_OBJECT
+ TQ_OBJECT
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMListPatternEdit with parent and name
*/
- PMListPatternEdit( TQWidget* parent, const char* name = 0 );
+ PMListPatternEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -38,12 +38,13 @@ class TQLabel;
public:
/**
- * Creates a PMListPatternEdit with parent and name
+ * Creates a PMListPatternEdit with tqparent and name
*/